Module observer

Module observer 

Modules

boxed_observer
callback_observer

Enums

Event
Flow
Whether an observer still accepts events, as reported by Observer::on_next.
Termination
Represents the termination state of an operation, which can either be completed successfully or with an error.

Traits

BoxedObserverExt
Observer
A trait for observing the progress and termination state of an operation.