Module switch
rx_rust
1.0.1
Module switch
Module Items
Structs
In rx_
rust::
operators::
combining
rx_rust
::
operators
::
combining
Module
switch
Structs

Switch
Converts an Observable that emits Observables into a single Observable that emits the items emitted by the most recently emitted of those Observables. See
https://reactivex.io/documentation/operators/switch.html