Module connectable_controller

Module connectable_controller 

Structs

ConnectableController
Multicasts a source Observable through a Subject, but waits until its connect method is called before subscribing to the source and emitting items to its observers. Subscribe to the multicast output through observable. See https://reactivex.io/documentation/operators/connect.html
Connected
State carried by a connected controller. Dropping it disconnects the source.
Disconnected
Marker for a connectable controller that is not connected to its source.