Module ref_count

Module ref_count 

Structs

Disposal
RefCount
Makes a ConnectableController behave like an ordinary Observable that automatically connects on the first subscription and disconnects when the last subscription is disposed. See https://reactivex.io/documentation/operators/refcount.html