Module subscribe_with_context

Module subscribe_with_context 

Structs

Disposal
SubscriptionContext
Context used by operator observers to serialize model updates and downstream events.
WeakSubscriptionContext
A non-owning reference to a SubscriptionContext.

Functions

subscribe_with_context
Creates a subscription backed by a shared, serialized context containing the downstream observer and a mutable model.
subscribe_with_context_owning_source
Creates a context subscription whose source subscription is owned by the context.

Type Aliases

OwningDisposal
The type-erased disposal of a context that owns its source subscription. Returned by subscribe_with_context_owning_source.