Structs
- Connectable
Controller - Multicasts a source
Observablethrough aSubject, but waits until itsconnectmethod is called before subscribing to the source and emitting items to its observers. Subscribe to the multicast output throughobservable. See https://reactivex.io/documentation/operators/connect.html - Connected
- State carried by a connected controller. Dropping it disconnects the source.
- Disconnected
- Marker for a connectable controller that is not connected to its source.