pub struct Bounded<T> { /* private fields */ }Expand description
Keeps at most capacity items, in order, and applies an Overflow rule beyond that. This
is onBackpressureBuffer with a capacity of other ReactiveX stacks.
The capacity is a NonZeroUsize: a buffer that holds nothing would yield nothing.
Latest is Bounded::drop_oldest with a capacity of one.
Implementations
Sourceimpl<T> Bounded<T>
impl<T> Bounded<T>
Sourcepub fn new(capacity: NonZeroUsize, overflow: Overflow) -> Self
pub fn new(capacity: NonZeroUsize, overflow: Overflow) -> Self
Keeps at most capacity items and applies overflow beyond that.
Sourcepub fn drop_oldest(capacity: NonZeroUsize) -> Self
pub fn drop_oldest(capacity: NonZeroUsize) -> Self
Keeps the newest capacity items; see Overflow::DropOldest.
Sourcepub fn drop_newest(capacity: NonZeroUsize) -> Self
pub fn drop_newest(capacity: NonZeroUsize) -> Self
Keeps the oldest capacity items; see Overflow::DropNewest.