pub struct OnPanic<T, F: FnOnce(T)>(/* private fields */);Expand description
Runs action with the guarded state if the current scope unwinds, and nothing otherwise.
See the module documentation for what the action may do. Use on_panic when there is
no state to carry.
Implementations