Structs
- Disposal
- Subscription
Context - Context used by operator observers to serialize model updates and downstream events.
- Weak
Subscription Context - A non-owning reference to a
SubscriptionContext.
Functions
- subscribe_
with_ context - Creates a subscription backed by a shared, serialized context containing the downstream observer and a mutable model.
- subscribe_
with_ context_ owning_ source - Creates a context subscription whose source subscription is owned by the context.
Type Aliases
- Owning
Disposal - The type-erased disposal of a context that owns its source subscription. Returned by
subscribe_with_context_owning_source.